@@ -21,18 +21,16 @@
 
 #include "cabri-filter.h"
 
-#include <qfile.h>
-#include <qregexp.h>
-#include <qstring.h>
-
 #include <QDebug>
-#include <klocale.h>
+#include <QFile>
+
+#include <KLocalizedString>
 
 #define KIG_CABRI_FILTER_PARSE_ERROR \
 { \
   QString locs = i18n( "An error was encountered at line %1 in file %2.", \
       __LINE__, __FILE__ ); \
-  m_filter->publicParseError( file, locs ); \
+  parseError( locs ); \
   return 0; \
 }
 
@@ -171,6 +169,13 @@ void CabriReader::initColorMap()
   }
 }
 
+
+void CabriReader::parseError(const QString& explanation) const
+{
+  m_filter->parseError( explanation );
+}
+
+
 QColor CabriReader::translateColor( const QString& s )
 {
   initColorMap();
@@ -605,7 +610,7 @@ CabriObject* CabriReader_v12::readObject( QFile& f )
         freeText = true;
       }
       else
-        readStyles( file, line, myobj );
+        readStyles( line, myobj );
     }
 
     line = CabriNS::readLine( f );
@@ -674,7 +679,7 @@ QColor CabriReader_v12::translateColor( const QString& s )
   return CabriReader::translateColor( s );
 }
 
-bool CabriReader_v12::readStyles( const QString& file, const QString& line, CabriObject_v12* myobj )
+bool CabriReader_v12::readStyles( const QString& line, CabriObject_v12* myobj )
 {
 #ifdef CABRI_DEBUG
   qDebug() << ">>>>>>>>> style line: \"" << line << "\"";
