@@ -48,14 +48,11 @@
 #include "../objects/transform_types.h"
 #include "../objects/vector_type.h"
 
-#include <math.h>
+#include <cmath>
 
-#include <qfile.h>
-#include <qnamespace.h>
 #include <QDomDocument>
-
-#include <kinputdialog.h>
-#include <klocale.h>
+#include <QInputDialog>
+#include <QFile>
 
 #undef DRGEO_DEBUG
 //#define DRGEO_DEBUG
@@ -124,7 +121,7 @@ KigDocument* KigFilterDrgeo::load( const QString& file )
   {
     // Dr. Geo file has more than 1 figure, let the user choose one...
     bool ok = true;
-    myfig = KInputDialog::getItem(
+    myfig = QInputDialog::getItem( nullptr,
                 i18n( "Dr. Geo Filter" ),
                 i18n( "The current Dr. Geo file contains more than one figure.\n"
                       "Please select which to import:" ),
@@ -150,7 +147,7 @@ KigDocument* KigFilterDrgeo::load( const QString& file )
 #endif
         bool grid = !e.attribute( "grid" ).isEmpty() &&
                     ( e.attribute( "grid" ) != "False" );
-        return importFigure( e.firstChild(), file, grid );
+        return importFigure( e.firstChild(), grid );
       }
     }
   }
@@ -182,7 +179,7 @@ static const Coordinate convertDrgeoHalflineParam( const double param, const Lin
   return p;
 }
 
-KigDocument* KigFilterDrgeo::importFigure( const QDomNode& f, const QString& file, const bool grid )
+KigDocument* KigFilterDrgeo::importFigure( const QDomNode& f, const bool grid )
 {
   KigDocument* ret = new KigDocument();
 
@@ -336,9 +333,9 @@ KigDocument* KigFilterDrgeo::importFigure( const QDomNode& f, const QString& fil
         else
         {
 //          oc = fact->constrainedPointCalcer( parents[0], value );
-          notSupported( file, i18n( "This Dr. Geo file contains a \"%1 %2\" object, "
-                                    "which Kig does not currently support.", domelem.tagName() , 
-                                      domelem.attribute( "type" ) ) );
+          notSupported( i18n( "This Dr. Geo file contains a \"%1 %2\" object, "
+                              "which Kig does not currently support.", domelem.tagName() , 
+                              domelem.attribute( "type" ) ) );
           return 0;
         }
       }
@@ -373,8 +370,8 @@ KigDocument* KigFilterDrgeo::importFigure( const QDomNode& f, const QString& fil
             type = ArcLineIntersectionType::instance();
           else
           {
-            notSupported( file, i18n( "This Dr. Geo file contains an intersection type, "
-                                      "which Kig does not currently support." ) );
+            notSupported( i18n( "This Dr. Geo file contains an intersection type, "
+                                "which Kig does not currently support." ) );
             return 0;
           }
           oc = new ObjectTypeCalcer( type, args );
@@ -394,9 +391,9 @@ KigDocument* KigFilterDrgeo::importFigure( const QDomNode& f, const QString& fil
         oc = new ObjectTypeCalcer( ScalingOverCenterType::instance(), parents );
       else
       {
-        notSupported( file, i18n( "This Dr. Geo file contains a \"%1 %2\" object, "
-                                  "which Kig does not currently support.", domelem.tagName() , 
-                                    domelem.attribute( "type" ) ) );
+        notSupported( i18n( "This Dr. Geo file contains a \"%1 %2\" object, "
+                            "which Kig does not currently support.", domelem.tagName() , 
+                            domelem.attribute( "type" ) ) );
         return 0;
       }
 #ifdef DRGEO_DEBUG
@@ -426,9 +423,9 @@ KigDocument* KigFilterDrgeo::importFigure( const QDomNode& f, const QString& fil
           type = CircleBCPType::instance();
         else
         {
-          notSupported( file, i18n( "This Dr. Geo file contains a \"%1 %2\" object, "
-                                    "which Kig does not currently support.", domelem.tagName() , 
-                                    domelem.attribute( "type" ) ) );
+          notSupported( i18n( "This Dr. Geo file contains a \"%1 %2\" object, "
+                              "which Kig does not currently support.", domelem.tagName() , 
+                              domelem.attribute( "type" ) ) );
           return 0;
         }
         oc = new ObjectTypeCalcer( type, parents );
@@ -439,9 +436,9 @@ KigDocument* KigFilterDrgeo::importFigure( const QDomNode& f, const QString& fil
           type = ArcBTPType::instance();
         else
         {
-          notSupported( file, i18n( "This Dr. Geo file contains a \"%1 %2\" object, "
-                                    "which Kig does not currently support.", domelem.tagName() , 
-                                    domelem.attribute( "type" ) ) );
+          notSupported( i18n( "This Dr. Geo file contains a \"%1 %2\" object, "
+                              "which Kig does not currently support.", domelem.tagName() , 
+                              domelem.attribute( "type" ) ) );
           return 0;
         }
         oc = new ObjectTypeCalcer( type, parents );
@@ -462,9 +459,9 @@ KigDocument* KigFilterDrgeo::importFigure( const QDomNode& f, const QString& fil
         }
         else
         {
-          notSupported( file, i18n( "This Dr. Geo file contains a \"%1 %2\" object, "
-                                    "which Kig does not currently support.", domelem.tagName() , 
-                                    domelem.attribute( "type" ) ) );
+          notSupported( i18n( "This Dr. Geo file contains a \"%1 %2\" object, "
+                              "which Kig does not currently support.", domelem.tagName() , 
+                              domelem.attribute( "type" ) ) );
           return 0;
         }
         oc = new ObjectTypeCalcer( type, parents );
@@ -478,9 +475,9 @@ KigDocument* KigFilterDrgeo::importFigure( const QDomNode& f, const QString& fil
         }
         else
         {
-          notSupported( file, i18n( "This Dr. Geo file contains a \"%1 %2\" object, "
-                                    "which Kig does not currently support.", domelem.tagName() , 
-                                    domelem.attribute( "type" ) ) );
+          notSupported( i18n( "This Dr. Geo file contains a \"%1 %2\" object, "
+                              "which Kig does not currently support.", domelem.tagName() , 
+                              domelem.attribute( "type" ) ) );
           return 0;
         }
         oc = new ObjectTypeCalcer( type, parents );
@@ -501,9 +498,9 @@ KigDocument* KigFilterDrgeo::importFigure( const QDomNode& f, const QString& fil
         oc = new ObjectTypeCalcer( ScalingOverCenterType::instance(), parents );
       else
       {
-        notSupported( file, i18n( "This Dr. Geo file contains a \"%1 %2\" object, "
-                                  "which Kig does not currently support.", domelem.tagName() , 
-                                  domelem.attribute( "type" ) ) );
+        notSupported( i18n( "This Dr. Geo file contains a \"%1 %2\" object, "
+                            "which Kig does not currently support.", domelem.tagName() , 
+                            domelem.attribute( "type" ) ) );
         return 0;
       }
 #ifdef DRGEO_DEBUG
@@ -628,9 +625,9 @@ KigDocument* KigFilterDrgeo::importFigure( const QDomNode& f, const QString& fil
       }
       else
       {
-        notSupported( file, i18n( "This Dr. Geo file contains a \"%1 %2\" object, "
-                                  "which Kig does not currently support.", domelem.tagName() , 
-                                  domelem.attribute( "type" ) ) );
+        notSupported( i18n( "This Dr. Geo file contains a \"%1 %2\" object, "
+                            "which Kig does not currently support.", domelem.tagName() , 
+                            domelem.attribute( "type" ) ) );
         return 0;
       }
 #ifdef DRGEO_DEBUG
@@ -646,9 +643,9 @@ KigDocument* KigFilterDrgeo::importFigure( const QDomNode& f, const QString& fil
       }
       else
       {
-        notSupported( file, i18n( "This Dr. Geo file contains a \"%1 %2\" object, "
-                                  "which Kig does not currently support.", domelem.tagName() , 
-                                  domelem.attribute( "type" ) ) );
+        notSupported( i18n( "This Dr. Geo file contains a \"%1 %2\" object, "
+                            "which Kig does not currently support.", domelem.tagName() , 
+                            domelem.attribute( "type" ) ) );
         return 0;
       }
 #ifdef DRGEO_DEBUG
@@ -687,9 +684,9 @@ KigDocument* KigFilterDrgeo::importFigure( const QDomNode& f, const QString& fil
         oc = fact->labelCalcer( text, Coordinate( x, y ), false, std::vector<ObjectCalcer*>(), *ret );
       else
       {
-        notSupported( file, i18n( "This Dr. Geo file contains a \"%1 %2\" object, "
-                                  "which Kig does not currently support.", domelem.tagName() , 
-                                  domelem.attribute( "type" ) ) );
+        notSupported( i18n( "This Dr. Geo file contains a \"%1 %2\" object, "
+                            "which Kig does not currently support.", domelem.tagName() , 
+                            domelem.attribute( "type" ) ) );
         return 0;
       }
     }
@@ -699,9 +696,9 @@ KigDocument* KigFilterDrgeo::importFigure( const QDomNode& f, const QString& fil
         oc = fact->locusCalcer( parents[0], parents[1] );
       else
       {
-        notSupported( file, i18n( "This Dr. Geo file contains a \"%1 %2\" object, "
-                                  "which Kig does not currently support.", domelem.tagName() , 
-                                  domelem.attribute( "type" ) ) );
+        notSupported( i18n( "This Dr. Geo file contains a \"%1 %2\" object, "
+                            "which Kig does not currently support.", domelem.tagName() , 
+                            domelem.attribute( "type" ) ) );
         return 0;
       }
 #ifdef DRGEO_DEBUG
@@ -719,9 +716,9 @@ KigDocument* KigFilterDrgeo::importFigure( const QDomNode& f, const QString& fil
 #ifdef DRGEO_DEBUG
       qDebug() << ">>>>>>>>> UNKNOWN OBJECT";
 #endif
-      notSupported( file, i18n( "This Dr. Geo file contains a \"%1 %2\" object, "
-                                "which Kig does not currently support.", domelem.tagName() , 
-                                domelem.attribute( "type" ) ) );
+      notSupported( i18n( "This Dr. Geo file contains a \"%1 %2\" object, "
+                          "which Kig does not currently support.", domelem.tagName() , 
+                          domelem.attribute( "type" ) ) );
       return 0;
     }
     curid++;
@@ -758,7 +755,7 @@ KigDocument* KigFilterDrgeo::importFigure( const QDomNode& f, const QString& fil
         w = 2;
     }
     QString ps = domelem.attribute( "style" );
-    int pointstyle = ObjectDrawer::pointStyleFromString( ps );
+    Kig::PointStyle pointstyle = Kig::pointStyleFromString( ps );
 // show this object?
     bool show = ( ( domelem.attribute( "masked" ) != "True" ) &&
                   ( domelem.attribute( "masked" ) != "Alway" ) );
