@@ -20,33 +20,28 @@
 
 #include "kig.h"
 
-
-#include <qevent.h>
-#include <qtimer.h>
-
 #include <QAction>
-#include <QStandardPaths>
+#include <QApplication>
+#include <QDropEvent>
 #include <QFileDialog>
-#include <QUrl>
+#include <QMessageBox>
 #include <QMimeData>
+#include <QProcess>
+#include <QStandardPaths>
+#include <QTimer>
+#include <QUrl>
 
+#include <KActionCollection>
 #include <KConfigGroup>
-#include <QDebug>
-#include <kedittoolbar.h>
-#include <kshortcutsdialog.h>
-#include <klibloader.h>
-#include <klocale.h>
-#include <kactioncollection.h>
-#include <kmessagebox.h>
-#include <krecentfilesaction.h>
-#include <kstandardaction.h>
-#include <ktip.h>
-#include <kxmlguifactory.h>
-#include <kapplication.h>
-#include <assert.h>
-
+#include <KEditToolBar>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KRecentFilesAction>
 #include <KService>
-#include <QFileDialog>
+#include <KSharedConfig>
+#include <KStandardAction>
+#include <KTipDialog>
+#include <KXMLGUIFactory>
 
 Kig::Kig()
   : KParts::MainWindow(), m_part( 0 )
@@ -151,7 +146,10 @@ void Kig::fileNew()
   // create a new window if we aren't in the "initial state" ( see
   // the KDE style guide on the file menu stuff...)
   if ( ! m_part->url().isEmpty() || m_part->isModified() )
-    (new Kig)->show();
+  {
+    QString kigBinary = QStandardPaths::findExecutable( "kig" );
+    QProcess::startDetached( kigBinary );
+  }
 }
 
 void Kig::openUrl( const QUrl &url )
@@ -174,7 +172,7 @@ void Kig::openUrl( const QUrl &url )
 
 void Kig::optionsConfigureToolbars()
 {
-  KConfigGroup configGroup = KGlobal::config()->group( "MainWindow");
+  KConfigGroup configGroup = KSharedConfig::openConfig()->group( "MainWindow" );
   saveMainWindowSettings( configGroup );
 
   // use the standard toolbar editor
@@ -186,7 +184,7 @@ void Kig::optionsConfigureToolbars()
 
 void Kig::applyNewToolbarConfig()
 {
-  applyMainWindowSettings( KGlobal::config()->group( "MainWindow") );
+  applyMainWindowSettings( KSharedConfig::openConfig()->group( "MainWindow") );
 }
 
 bool Kig::queryClose()
@@ -217,12 +215,7 @@ void Kig::fileOpen()
 
   if ( currentDir.isNull() )
   {
-    const QStringList documentsPath = QStandardPaths::standardLocations( QStandardPaths::DocumentsLocation );
-
-    if ( !documentsPath.empty() )
-    {
-      currentDir = documentsPath[0];
-    }
+    currentDir = QStandardPaths::writableLocation( QStandardPaths::DocumentsLocation );
   }
 
   const QString file_name = QFileDialog::getOpenFileName(0, QString(), currentDir,  m_mimeTypes.join( " " ) );
