@@ -37,16 +37,16 @@ class BaseMode
   std::vector<ObjectHolder*> moco;
 
 public:
-  void leftClicked( QMouseEvent* e, KigWidget* v );
-  void leftMouseMoved( QMouseEvent*, KigWidget* );
-  void leftReleased( QMouseEvent* e, KigWidget* v );
-  void midClicked( QMouseEvent* e, KigWidget* v );
-  void midReleased( QMouseEvent* e, KigWidget* v );
-  void rightClicked( QMouseEvent*, KigWidget* );
-  void mouseMoved( QMouseEvent* e, KigWidget* v );
+  void leftClicked( QMouseEvent* e, KigWidget* v ) Q_DECL_OVERRIDE;
+  void leftMouseMoved( QMouseEvent*, KigWidget* ) Q_DECL_OVERRIDE;
+  void leftReleased( QMouseEvent* e, KigWidget* v ) Q_DECL_OVERRIDE;
+  void midClicked( QMouseEvent* e, KigWidget* v ) Q_DECL_OVERRIDE;
+  void midReleased( QMouseEvent* e, KigWidget* v ) Q_DECL_OVERRIDE;
+  void rightClicked( QMouseEvent*, KigWidget* ) Q_DECL_OVERRIDE;
+  void mouseMoved( QMouseEvent* e, KigWidget* v ) Q_DECL_OVERRIDE;
 
 protected:
-  void enableActions();
+  void enableActions() Q_DECL_OVERRIDE;
 
   std::vector<ObjectHolder*> oco();
   QPoint pointLocation();
